[PATCH] Automatically autoload bashcompinit for ZSH, when needed

[Date Prev][Date Next][Thread Prev][Thread Next][Date Index][Thread Index]

 



If bashcompinit has not already been autoloaded, do so
automatically, as it is required to properly parse the
git-completion file with ZSH.

Signed-off-by: Marius Storm-Olsen <mstormo@xxxxxxxxx>
---
 Since I rebased the previous version, I didn't notice that some
 effort had already gone into making git-completion.bash parsable
 with ZSH.
 
 I've therefore dropped everything from the previous patch, and
 rather added some code to automatically do the required steps
 for ZSH, should it not have been done already; as well as
 simplified the 'documentation'.
 
 My appologies for not more closely inspecting the recent changes
 to the file.
 
 contrib/completion/git-completion.bash |   19 +++++++++++--------
 1 files changed, 11 insertions(+), 8 deletions(-)

diff --git a/contrib/completion/git-completion.bash b/contrib/completion/git-completion.bash
index 840ae38..35d1c9b 100755
--- a/contrib/completion/git-completion.bash
+++ b/contrib/completion/git-completion.bash
@@ -1,6 +1,6 @@
 #!bash
 #
 # bash completion support for core Git.
 #
 # Copyright (C) 2006,2007 Shawn O. Pearce <spearce@xxxxxxxxxxx>
 # Conceptually based on gitcompletion (http://gitweb.hawaga.org.uk/).
@@ -18,16 +18,12 @@
 # To use these routines:
 #
 #    1) Copy this file to somewhere (e.g. ~/.git-completion.sh).
-#    2) Added the following line to your .bashrc:
-#        source ~/.git-completion.sh
-#
-#       Or, add the following lines to your .zshrc:
-#        autoload bashcompinit
-#        bashcompinit
+#    2) Added the following line to your .bashrc/.zshrc:
 #        source ~/.git-completion.sh
 #
 #    3) Consider changing your PS1 to also show the current branch:
-#        PS1='[\u@\h \W$(__git_ps1 " (%s)")]\$ '
+#         Bash: PS1='[\u@\h \W$(__git_ps1 " (%s)")]\$ '
+#         ZSH:  PS1='[%n@%m %c$(__git_ps1 " (%s)")]\$ '
 #
 #       The argument to __git_ps1 will be displayed only if you
 #       are currently in a git repository.  The %s token will be
@@ -77,6 +73,13 @@
 #       git@xxxxxxxxxxxxxxx
 #
 
+if [[ -n ${ZSH_VERSION-} ]]; then
+	if ! bashcompinit >/dev/null 2>&1; then
+		autoload -U bashcompinit
+		bashcompinit
+	fi
+fi
+
 case "$COMP_WORDBREAKS" in
 *:*) : great ;;
 *)   COMP_WORDBREAKS="$COMP_WORDBREAKS:"
@@ -1,6 +1,6 @@
 #!bash
 #
-# bash completion support for core Git.
+# bash/zsh completion support for core Git.
 #
 # Copyright (C) 2006,2007 Shawn O. Pearce <spearce@xxxxxxxxxxx>
-- 
1.7.5.rc2.4.g4d8b3

--
To unsubscribe from this list: send the line "unsubscribe git" in
the body of a message to majordomo@xxxxxxxxxxxxxxx
More majordomo info at  http://vger.kernel.org/majordomo-info.html


[Index of Archives]     [Linux Kernel Development]     [Gcc Help]     [IETF Annouce]     [DCCP]     [Netdev]     [Networking]     [Security]     [V4L]     [Bugtraq]     [Yosemite]     [MIPS Linux]     [ARM Linux]     [Linux Security]     [Linux RAID]     [Linux SCSI]     [Fedora Users]